@@ -1,7 +1,10 @@
+use lib '../blib/lib';
 use strict;
 use Jabber::JAX::Component;
 
-my $c = new Jabber::JAX::Component(
+my $c = 0;
+
+my $conn = new Jabber::JAX::Component(
       component   => "echocomp",
       secret      => "mysecret",
       host        => "localhost",
@@ -10,14 +13,16 @@ my $c = new Jabber::JAX::Component(
 
       sub {
             my ( $rc, $p ) = @_;
+	    print STDERR "Doint number ".$c++."\n";
             my $e = $p->getElement();
             my $to = $e->getAttrib('to');
             $e->putAttrib('to', $e->getAttrib('from'));
             $e->putAttrib('from', $to);
             $rc->deliver( $p );
+            $rc->stop() if $c == 50;
 
           }
      );
 
-$c->start();
+$conn->start();
 
